Dotfiles Management
-------------------

**syndot** is a python library for Linux and macOS dotfiles management.

.. list-table::
   :stub-columns: 1
   :widths: auto
   :width: 100%

   * - Release
     - |pypi_release| |build|
   * - Versioning
     - |supported_python_versions| |semver|
   * - Tests
     - |linux_tests| |macos_tests| |test_coverage|
   * - Documentation
     - |docs|
   * - Code Quality
     - |codefactor_grade| |codacy_grade| |issues|
   * - License
     - |license|

.. |pypi_release| image:: https://img.shields.io/pypi/v/syndot?label=release&color=blue
   :target: https://pypi.org/project/syndot/
   :alt: PyPI - Library Version

.. |build| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/syndot/release.yml.svg?logo=github
   :target: https://github.com/AndreaBlengino/syndot/actions/workflows/release.yml
   :alt: Package Build

.. |supported_python_versions| image:: https://img.shields.io/pypi/pyversions/syndot?logo=python&logoColor=gold
   :target: https://pypi.org/project/syndot/
   :alt: PyPI - Supported Python Versions

.. |semver| image:: https://img.shields.io/badge/semver-2.0.0-blue.svg
   :target: https://semver.org/

.. |linux_tests| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/syndot/linux_test.yml.svg?logo=linux&logoColor=white&label=Linux
   :target: https://github.com/AndreaBlengino/syndot/actions/workflows/linux_test.yml
   :alt: Linux Tests

.. |macos_tests| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/syndot/macos_test.yml.svg?logo=apple&label=macOS
   :target: https://github.com/AndreaBlengino/syndot/actions/workflows/macos_test.yml
   :alt: macOS Tests

.. |test_coverage| image:: https://img.shields.io/codecov/c/github/AndreaBlengino/syndot/master?logo=codecov
   :target: https://codecov.io/gh/AndreaBlengino/syndot
   :alt: Test Coverage

.. |docs| image:: https://img.shields.io/readthedocs/syndot/latest?logo=read%20the%20docs
   :target: https://syndot.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Build Status

.. |codefactor_grade| image:: https://img.shields.io/codefactor/grade/github/AndreaBlengino/syndot?logo=codefactor&label=CodeFactor
   :target: https://www.codefactor.io/repository/github/andreablengino/syndot
   :alt: CodeFactor Grade

.. |codacy_grade| image:: https://img.shields.io/codacy/grade/132c2f3d93344ae0934ea808bbf17f05?logo=codacy&label=Codacy
   :target: https://app.codacy.com/gh/AndreaBlengino/syndot/dashboard
   :alt: Codacy Grade

.. |issues| image:: https://img.shields.io/github/issues/AndreaBlengino/syndot?logo=github
   :target: https://github.com/AndreaBlengino/syndot/issues
   :alt: Open Issues

.. |license| image:: https://img.shields.io/badge/License-GPLv3-blue.svg
   :target: https://github.com/AndreaBlengino/syndot/blob/master/LICENSE
   :alt: License


References
----------

- `Installation <https://syndot.readthedocs.io/en/latest/get_started.html>`_
- `PyPI <https://pypi.org/project/syndot/>`_
- `Documentation <https://syndot.readthedocs.io/en/latest/?badge=latest>`_
- `Issue tracker <https://github.com/AndreaBlengino/syndot/issues>`_
- `Source code <https://github.com/AndreaBlengino/syndot/tree/master/syndot>`_
- `GNU General Public License v3.0 <https://github.com/AndreaBlengino/syndot/blob/master/LICENSE>`_
- `Release Notes <https://syndot.readthedocs.io/en/latest/release_notes/index.html>`_


Contributing
------------

The syndot project welcomes your expertise and enthusiasm!
All contributions, bug reports, bug fixes, documentation improvements, enhancements and ideas are welcome.
Writing code isn't the only way to contribute to syndot. You can also:

- develop tutorials, presentations and other educational materials,
- maintain and improve the `documentation <https://syndot.readthedocs.io/en/latest/?badge=latest>`_,
- help with outreach and onboard new contributors.

Have a look at the `contributing guide <https://github.com/AndreaBlengino/syndot/blob/master/.github/CONTRIBUTING.md>`_.
If you are new to contributing to open source, `this guide <https://opensource.guide/how-to-contribute/>`_ helps explain
why, what, and how to successfully get involved.
